summaryrefslogtreecommitdiffstats
path: root/src/common/nokde/nokde_kaboutdata.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 00:15:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 00:15:53 +0000
commit0aaa8e3fc8f8a1481333b564f0922277c8d8ad59 (patch)
treeb95c0ca86c4876dd139af376b9f4afd8917cf0cd /src/common/nokde/nokde_kaboutdata.h
parentb79a2c28534cf09987eeeba3077fff9236df182a (diff)
downloadpiklab-0aaa8e3fc8f8a1481333b564f0922277c8d8ad59.tar.gz
piklab-0aaa8e3fc8f8a1481333b564f0922277c8d8ad59.zip
TQt4 port piklab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/piklab@1238822 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/common/nokde/nokde_kaboutdata.h')
-rw-r--r--src/common/nokde/nokde_kaboutdata.h96
1 files changed, 48 insertions, 48 deletions
diff --git a/src/common/nokde/nokde_kaboutdata.h b/src/common/nokde/nokde_kaboutdata.h
index 13076d4..01a8e74 100644
--- a/src/common/nokde/nokde_kaboutdata.h
+++ b/src/common/nokde/nokde_kaboutdata.h
@@ -21,16 +21,16 @@
*
*/
-#include <qglobal.h>
-#if QT_VERSION < 0x040000
-# include <qvaluelist.h>
+#include <tqglobal.h>
+#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
+# include <tqvaluelist.h>
#else
-# include <Qt3Support/Q3ValueList>
-# define QValueList Q3ValueList
-# include <QStringList>
+# include <TQt3Support/Q3ValueList>
+# define TQValueList Q3ValueList
+# include <TQStringList>
#endif
-#include <qstring.h>
-//#include <qimage.h>
+#include <tqstring.h>
+//#include <tqimage.h>
#include "nokde_klocale.h"
@@ -85,37 +85,37 @@ public:
}
/**
* @internal
* Don't use. Required by QValueList
*/
KAboutPerson() {}
/**
* The person's name
* @return the person's name (can be QString::null, if it has been
* constructed with a null name)
*/
- QString name() const;
+ TQString name() const;
/**
* The person's task
* @return the person's task (can be QString::null, if it has been
* constructed with a null task)
*/
- QString task() const;
+ TQString task() const;
/**
* The person's email address
* @return the person's email address (can be QString::null, if it has been
* constructed with a null email)
*/
- QString emailAddress() const;
+ TQString emailAddress() const;
/**
* The home page or a relevant link
* @return the persons home page (can be QString::null, if it has been
* constructed with a null home page)
*/
- QString webAddress() const;
+ TQString webAddress() const;
private:
const char *mName;
@@ -149,26 +149,26 @@ public:
*
* @param emailAddress The email address of the person.
*/
- KAboutTranslator(const QString & name=QString::null,
- const QString & emailAddress=QString::null);
+ KAboutTranslator(const TQString & name=TQString(),
+ const TQString & emailAddress=TQString());
/**
* The translator's name
* @return the translators's name (can be QString::null, if it has been
* constructed with a null name)
*/
- QString name() const;
+ TQString name() const;
/**
* The translator's email
* @return the translator's email address (can be QString::null, if it has been
* constructed with a null email)
*/
- QString emailAddress() const;
+ TQString emailAddress() const;
private:
- QString mName;
- QString mEmail;
+ TQString mName;
+ TQString mEmail;
KAboutTranslatorPrivate* d;
};
@@ -204,8 +204,8 @@ class KDECORE_EXPORT KAboutData
License_LGPL_V2 = 2,
License_BSD = 3,
License_Artistic = 4,
- License_QPL = 5,
- License_QPL_V1_0 = 5
+ License_TQPL = 5,
+ License_TQPL_V1_0 = 5
};
public:
@@ -352,7 +352,7 @@ class KDECORE_EXPORT KAboutData
*
* @param file File containing the license text.
*/
- void setLicenseTextFile( const QString &file );
+ void setLicenseTextFile( const TQString &file );
/**
* Defines the program name used internally.
@@ -379,7 +379,7 @@ class KDECORE_EXPORT KAboutData
* @see programLogo()
* @since 3.4
*/
-// void setProgramLogo(const QImage& image);
+// void setProgramLogo(const TQImage& image);
/**
* Defines the program version string.
@@ -469,7 +469,7 @@ class KDECORE_EXPORT KAboutData
* Returns the translated program name.
* @return the program name (translated).
*/
- QString programName() const;
+ TQString programName() const;
/**
* Returns the program logo image.
@@ -477,63 +477,63 @@ class KDECORE_EXPORT KAboutData
* no custom application logo defined.
* @since 3.4
*/
-// QImage programLogo() const;
+// TQImage programLogo() const;
/**
* Returns the program's version.
* @return the version string.
*/
- QString version() const;
+ TQString version() const;
/**
* Returns a short, translated description.
* @return the short description (translated). Can be
- * QString::null if not set.
+ * TQString() if not set.
*/
- QString shortDescription() const;
+ TQString shortDescription() const;
/**
* Returns the application homepage.
* @return the application homepage URL. Can be QString::null if
* not set.
*/
- QString homepage() const;
+ TQString homepage() const;
/**
* Returns the email address for bugs.
* @return the email address where to report bugs.
*/
- QString bugAddress() const;
+ TQString bugAddress() const;
/**
* Returns a list of authors.
* @return author information (list of persons).
*/
- const QValueList<KAboutPerson> authors() const;
+ const TQValueList<KAboutPerson> authors() const;
/**
* Returns a list of persons who contributed.
* @return credit information (list of persons).
*/
- const QValueList<KAboutPerson> credits() const;
+ const TQValueList<KAboutPerson> credits() const;
/**
* Returns a list of translators.
* @return translators information (list of persons)
*/
- const QValueList<KAboutTranslator> translators() const;
+ const TQValueList<KAboutTranslator> translators() const;
/**
* Returns a message about the translation team.
* @return a message about the translation team
*/
- static QString aboutTranslationTeam();
+ static TQString aboutTranslationTeam();
/**
* Returns a translated, free form text.
* @return the free form text (translated). Can be QString::null if not set.
*/
- QString otherText() const;
+ TQString otherText() const;
/**
* Returns the license. If the licenseType argument of the constructor has been
@@ -542,13 +542,13 @@ class KDECORE_EXPORT KAboutData
*
* @return The license text.
*/
- QString license() const;
+ TQString license() const;
/**
* Returns the copyright statement.
- * @return the copyright statement. Can be QString::null if not set.
+ * @return the copyright statement. Can be TQString() if not set.
*/
- QString copyrightStatement() const;
+ TQString copyrightStatement() const;
private:
const char *mAppName;
@@ -560,8 +560,8 @@ class KDECORE_EXPORT KAboutData
const char *mOtherText;
const char *mHomepageAddress;
const char *mBugEmailAddress;
- QValueList<KAboutPerson> mAuthorList;
- QValueList<KAboutPerson> mCreditList;
+ TQValueList<KAboutPerson> mAuthorList;
+ TQValueList<KAboutPerson> mCreditList;
const char *mLicenseText;
KAboutDataPrivate *d;
@@ -85,37 +85,37 @@ public:
/**
* @internal
- * Don't use. Required by QValueList
+ * Don't use. Required by TQValueList
*/
KAboutPerson() {}
@@ -85,37 +85,37 @@ public:
/**
* The person's name
- * @return the person's name (can be QString::null, if it has been
+ * @return the person's name (can be TQString(), if it has been
* constructed with a null name)
*/
@@ -85,37 +85,37 @@ public:
/**
* The person's task
- * @return the person's task (can be QString::null, if it has been
+ * @return the person's task (can be TQString(), if it has been
* constructed with a null task)
*/
@@ -85,37 +85,37 @@ public:
/**
* The person's email address
- * @return the person's email address (can be QString::null, if it has been
+ * @return the person's email address (can be TQString(), if it has been
* constructed with a null email)
*/
@@ -85,37 +85,37 @@ public:
/**
* The home page or a relevant link
- * @return the persons home page (can be QString::null, if it has been
+ * @return the persons home page (can be TQString(), if it has been
* constructed with a null home page)
*/
@@ -149,26 +149,26 @@ public:
/**
* The translator's name
- * @return the translators's name (can be QString::null, if it has been
+ * @return the translators's name (can be TQString(), if it has been
* constructed with a null name)
*/
@@ -149,26 +149,26 @@ public:
/**
* The translator's email
- * @return the translator's email address (can be QString::null, if it has been
+ * @return the translator's email address (can be TQString(), if it has been
* constructed with a null email)
*/
@@ -477,63 +477,63 @@ class KDECORE_EXPORT KAboutData
/**
* Returns the application homepage.
- * @return the application homepage URL. Can be QString::null if
+ * @return the application homepage URL. Can be TQString() if
* not set.
*/
@@ -477,63 +477,63 @@ class KDECORE_EXPORT KAboutData
/**
* Returns a translated, free form text.
- * @return the free form text (translated). Can be QString::null if not set.
+ * @return the free form text (translated). Can be TQString() if not set.
*/